@@ -1,8 +1,10 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE PolyKinds, GADTs #-}
 
 module Dep2 where
 
-data G (a :: k) where
+import Data.Kind (Type)
+
+type G :: k -> Type
+data G a where
   G1 :: G Int
   G2 :: G Maybe
