@@ -1,12 +1,14 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE RankNTypes, PolyKinds, GADTs, UndecidableSuperClasses, UndecidableInstances #-}
 
 module T11520 where
 
+import Data.Kind (Type, Constraint)
 import GHC.Types hiding (TyCon)
 
-data TypeRep (a :: k)
+type TypeRep :: k -> Type
+data TypeRep a
 
+type Typeable :: k -> Constraint
 class Typeable k => Typeable (a :: k) where
     typeRep :: TypeRep a
 
