@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE TypeApplications, ScopedTypeVariables, GADTs, RankNTypes,
              PolyKinds, KindSignatures #-}
 {-# OPTIONS_GHC -O2 #-} -- We are provoking a bug in GHC.Core.Opt.SpecConstr
@@ -10,7 +9,8 @@ import Data.Proxy
 
 data T a = T1 (T a) | T2
 
-data K (a :: k) where
+type K :: k -> Type
+data K a where
   K1 :: K (a :: Type)
   K2 :: K a
 
